function [X_use, b, bint, r, rint, stats] = rsstepwisefit (y, X, pent, prem)
% RSSTEPWISEFIT - Just a wrapper for Matlab's stepwisefit which makes the syntax the same as for Octave's stepwisefit. Version 0.1.6.
%
% The syntax is
%  [X_use, b, bint, r, rint, stats] = rsstepwisefit (y, X, [penter], [premove])
%
% Arguments
% y is an N by 1 column vector of data to fit.
% X is a matrix with N rows containing the values of the possible predictors to be tested for adding to the model, which has NO CONSTANT COLUMN OF ONES.
% penter is a voluntary number, the maximum allowed p-value for a term to be added. The default is 0.05.
% premove is also voluntary. It is the minimum p-value for a term to be removed. Default is maximum of the value of 'penter' and 0.10.
%
% Return values
% X_use is a row vector indicating which columns of X were accepted in the final model, sorted in order of significance.
% [b, bint, r, rint, stats] is the output of the command regress, applied to the final model suggested by stepwisefit. Confidence intervals have confidence 1-penter.
%
% References
% None needed, this is trivial.


% Copyright (C) 2015 Mikael Kurula <mkurula@abo.fi>
%
% This program is free software; you can redistribute it and/or modify it under
% the terms of the GNU General Public License as published by the Free Software
% Foundation; either version 3 of the License, or (at your option) any later
% version.
%
% This program is distributed in the hope that it will be useful, but WITHOUT
% ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
% FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
% details.
%
% You should have received a copy of the GNU General Public License along with
% this program; if not, see <http://www.gnu.org/licenses/>.
%
% Author: Mikael Kurula <mkurula@abo.fi>, 2015


% Check input
if nargin < 2 || nargin > 4,
    error('Wrong number of arguments. Try help rsstepwisefit for instructions.') ;
end
if size(y,2) > 1,
    error('y has more than one column. Try help rsstepwisefit for instructions.');
end


% Call Matlab's stepwisefit and define return values
N=length(y);
switch nargin
	case 2
		[~, ~, ~, inmodel, extras]=stepwisefit(X,y, 'display', 'off');
    X_use=find(inmodel);
    [~, ind]=sort(extras.PVAL(X_use));
    X_use=X_use(ind);
    Xtrim=[ones(N,1), X(:,X_use)];
    [b, bint, r, rint, stats] = regress (y, Xtrim);
	case 3
		[~, ~, ~, inmodel, extras]=stepwisefit(X,y, 'display', 'off', 'penter', pent);
    X_use=find(inmodel);
    Xtrim=[ones(N,1), X(:,X_use)];
    [b, bint, r, rint, stats] = regress (y, Xtrim, pent);
	case 4
		[~, ~, ~, inmodel, extras]=stepwisefit(X,y, 'display', 'off', 'penter', pent, 'premove', prem);
    X_use=find(inmodel);
    Xtrim=[ones(N,1), X(:,X_use)];
    [b, bint, r, rint, stats] = regress (y, Xtrim, pent);
end

end